@@ -119,6 +119,7 @@ kSlideShowSaver::kSlideShowSaver( WId id ): KScreenSaver(id)
   {
     mGeoList.append(mScreenGeo(width(), height(), 0, 0));
   }
+  setAttribute(Qt::WA_NoSystemBackground);
   createNextScreen();
 }
 
@@ -692,6 +693,13 @@ void kSlideShowSaver::restart()
 
 //-----------------------------------------------------------------------------
 void kSlideShowSaver::slotTimeout()
+{
+  update();
+}
+
+
+//-----------------------------------------------------------------------------
+void kSlideShowSaver::paintEvent(QPaintEvent *)
 {
   int tmout = -1;
   int i;
